@@ -3,7 +3,7 @@ BEGIN {
   $Reply::Plugin::CarpReply::AUTHORITY = 'cpan:DOY';
 }
 {
-  $Reply::Plugin::CarpReply::VERSION = '0.04';
+  $Reply::Plugin::CarpReply::VERSION = '0.05';
 }
 use strict;
 use warnings;
@@ -21,21 +21,11 @@ sub new {
     $self->{stacktrace} = Devel::StackTrace::WithLexicals->new(
         ignore_class => ['Reply', 'Carp::Reply', __PACKAGE__],
     );
-    $self->{frame_index} = 0;
+    $self->_frame_index(0);
 
     return $self;
 }
 
-sub compile {
-    my $self = shift;
-    my ($next, $line, %opts) = @_;
-
-    $opts{environment} = $self->_frame->lexicals;
-    $opts{package}     = $self->_frame->package;
-
-    return $next->($line, %opts);
-}
-
 sub command_backtrace {
     my $self = shift;
     print "Backtrace:\n";
@@ -128,6 +118,12 @@ sub _frame_index {
         printf "Now at %s:%s (frame $index)\n",
             $self->_frame->filename,
             $self->_frame->line;
+
+        $self->publish(
+            'lexical_environment',
+            default => $self->_frame->lexicals
+        );
+        $self->publish('package', $self->_frame->package);
     }
 }
 
@@ -149,7 +145,7 @@ Reply::Plugin::CarpReply - plugin that implements most of the functionality of C
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
